@@ -28,9 +28,6 @@ public:
 
     void append(const QPointF pt,bool update = true);
 
-    /// Append the last point
-    void appendLast(const QPointF pt);
-
     void clear();
 
     void setPen(const QPen& val);
