@@ -33,6 +33,7 @@ Maemo5Application::Maemo5Application(QObject *parent) :
             this, SLOT(setWinSize()));
 #else
     editor = new PageEditorWindow();
+    editor->setAttribute(Qt::WA_DeleteOnClose,false);
 #endif
 
     connect(editor,SIGNAL(saved(int)),
@@ -61,9 +62,14 @@ int Maemo5Application::exec(){
 
     ConfigEntity colorEntity;
     ConfigEntity brushTypeEntity;
+    ConfigEntity backgroundColorEntity;
 
     colorEntity.load("pen-color","#000000");
     brushTypeEntity.load("pen-brush-type","2");
+    backgroundColorEntity.load("background-color","#ffffff");
+
+    QColor color(backgroundColorEntity.value());
+    editor->setBackgroundColor(color);
 
     Drawpad *drawpad = editor->drawpad();
     drawpad->setColor(QColor(colorEntity.value()));
@@ -79,9 +85,13 @@ int Maemo5Application::exec(){
     QString val;
     val.setNum(drawpad->brushType());
     brushTypeEntity.setValue(val);
+    backgroundColorEntity.setValue(editor->backgroundColor().name());
+
+    // Save
 
     colorEntity.save();
     brushTypeEntity.save();
+    backgroundColorEntity.save();
 
     return ret;
 }
