@@ -2,9 +2,9 @@
 #include <QtCore>
 
 #include "mainwindow.h"
-#include "storage.h"
-#include "tables.h"
-
+//#include "storage.h"
+//#include "tables.h"
+#include "paperbackground.h"
 
 int main(int argc, char *argv[])
 {
@@ -12,8 +12,10 @@ int main(int argc, char *argv[])
     a.setOrganizationName("penpen");
     a.setApplicationName("sketchbook");
 
+    /*
     Storage *storage = Storage::instance();
     storage->open();
+    */
 
     MainWindow w;
 #if defined(Q_WS_S60)
@@ -28,6 +30,10 @@ int main(int argc, char *argv[])
 
     Drawpad* drawpad = w.drawpad();
 
+//    PaperBackground bg;
+//    bg.setColor(Qt::blue);
+//    drawpad->paper()->setBackground(bg);
+
     QFile file("drawpad.xml");
     if (file.open(QIODevice::ReadOnly)) {
         QByteArray data = file.readAll();
@@ -40,6 +46,7 @@ int main(int argc, char *argv[])
         file.close();
     }
 
+    drawpad->refresh();
     int ret =  a.exec();
 
     QDomDocument doc = drawpad->toXml();
